==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/fluidrelay/kotlin/FluidRelayServer.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.fluidrelay.kotlin

import com.pulumi.azurenative.fluidrelay.kotlin.outputs.EncryptionPropertiesResponse
import com.pulumi.azurenative.fluidrelay.kotlin.outputs.FluidRelayEndpointsResponse
import com.pulumi.azurenative.fluidrelay.kotlin.outputs.IdentityResponse
import com.pulumi.azurenative.fluidrelay.kotlin.outputs.SystemDataResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import com.pulumi.azurenative.fluidrelay.kotlin.outputs.EncryptionPropertiesResponse.Companion.toKotlin as encryptionPropertiesResponseToKotlin
import com.pulumi.azurenative.fluidrelay.kotlin.outputs.FluidRelayEndpointsResponse.Companion.toKotlin as fluidRelayEndpointsResponseToKotlin
import com.pulumi.azurenative.fluidrelay.kotlin.outputs.IdentityResponse.Companion.toKotlin as identityResponseToKotlin
import com.pulumi.azurenative.fluidrelay.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin

/**
 * Builder for [FluidRelayServer].
 */
@PulumiTagMarker
public class FluidRelayServerResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: FluidRelayServerArgs = FluidRelayServerArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend FluidRelayServerArgsBuilder.() -> Unit) {
        val builder = FluidRelayServerArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): FluidRelayServer {
        val builtJavaResource =
            com.pulumi.azurenative.fluidrelay.FluidRelayServer(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return FluidRelayServer(builtJavaResource)
    }
}

/**
 * A FluidRelay Server.
 * Azure REST API version: 2022-06-01. Prior API version in Azure Native 1.x: 2021-03-12-preview.
 * Other available API versions: 2021-06-15-preview.
 * ## Example Usage
 * ### Create a Fluid Relay server
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var fluidRelayServer = new AzureNative.FluidRelay.FluidRelayServer("fluidRelayServer", new()
 *     {
 *         FluidRelayServerName = "myFluidRelayServer",
 *         Identity = new AzureNative.FluidRelay.Inputs.IdentityArgs
 *         {
 *             Type = AzureNative.FluidRelay.ResourceIdentityType.SystemAssigned,
 *         },
 *         Location = "west-us",
 *         ResourceGroup = "myResourceGroup",
 *         Storagesku = "basic",
 *         Tags =
 *         {
 *             { "Category", "sales" },
 *         },
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/fluidrelay/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := fluidrelay.NewFluidRelayServer(ctx, "fluidRelayServer", &fluidrelay.FluidRelayServerArgs{
 * 			FluidRelayServerName: pulumi.String("myFluidRelayServer"),
 * 			Identity: &fluidrelay.IdentityArgs{
 * 				Type: fluidrelay.ResourceIdentityTypeSystemAssigned,
 * 			},
 * 			Location:      pulumi.String("west-us"),
 * 			ResourceGroup: pulumi.String("myResourceGroup"),
 * 			Storagesku:    pulumi.String("basic"),
 * 			Tags: pulumi.StringMap{
 * 				"Category": pulumi.String("sales"),
 * 			},
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.fluidrelay.FluidRelayServer;
 * import com.pulumi.azurenative.fluidrelay.FluidRelayServerArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var fluidRelayServer = new FluidRelayServer("fluidRelayServer", FluidRelayServerArgs.builder()
 *             .fluidRelayServerName("myFluidRelayServer")
 *             .identity(Map.of("type", "SystemAssigned"))
 *             .location("west-us")
 *             .resourceGroup("myResourceGroup")
 *             .storagesku("basic")
 *             .tags(Map.of("Category", "sales"))
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:fluidrelay:FluidRelayServer myFluidRelayServer /subscriptions/{subscriptionId}/resourceGroups/{resourceGroup}/providers/Microsoft.FluidRelay/fluidRelayServers/{fluidRelayServerName}
 * ```
 */
public class FluidRelayServer internal constructor(
    override val javaResource: com.pulumi.azurenative.fluidrelay.FluidRelayServer,
) : KotlinCustomResource(javaResource, FluidRelayServerMapper) {
    /**
     * All encryption configuration for a resource.
     */
    public val encryption: Output<EncryptionPropertiesResponse>?
        get() = javaResource.encryption().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    encryptionPropertiesResponseToKotlin(args0)
                })
            }).orElse(null)
        })

    /**
     * The Fluid Relay Service endpoints for this server.
     */
    public val fluidRelayEndpoints: Output<FluidRelayEndpointsResponse>
        get() = javaResource.fluidRelayEndpoints().applyValue({ args0 ->
            args0.let({ args0 ->
                fluidRelayEndpointsResponseToKotlin(args0)
            })
        })

    /**
     * The Fluid tenantId for this server
     */
    public val frsTenantId: Output<String>
        get() = javaResource.frsTenantId().applyValue({ args0 -> args0 })

    /**
     * The type of identity used for the resource.
     */
    public val identity: Output<IdentityResponse>?
        get() = javaResource.identity().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    identityResponseToKotlin(args0)
                })
            }).orElse(null)
        })

    /**
     * The geo-location where the resource lives
     */
    public val location: Output<String>
        get() = javaResource.location().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Provision states for FluidRelay RP
     */
    public val provisioningState: Output<String>?
        get() = javaResource.provisioningState().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Sku of the storage associated with the resource
     */
    public val storagesku: Output<String>?
        get() = javaResource.storagesku().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * System meta data for this resource, including creation and modification information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * Resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object FluidRelayServerMapper : ResourceMapper<FluidRelayServer> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.fluidrelay.FluidRelayServer::class == javaResource::class

    override fun map(javaResource: Resource): FluidRelayServer = FluidRelayServer(
        javaResource as
            com.pulumi.azurenative.fluidrelay.FluidRelayServer,
    )
}

/**
 * @see [FluidRelayServer].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [FluidRelayServer].
 */
public suspend fun fluidRelayServer(
    name: String,
    block: suspend FluidRelayServerResourceBuilder.() -> Unit,
): FluidRelayServer {
    val builder = FluidRelayServerResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [FluidRelayServer].
 * @param name The _unique_ name of the resulting resource.
 */
public fun fluidRelayServer(name: String): FluidRelayServer {
    val builder = FluidRelayServerResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/fluidrelay/kotlin/FluidRelayServer.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.fluidrelay.kotlin

import com.pulumi.azurenative.fluidrelay.kotlin.outputs.EncryptionPropertiesResponse
import com.pulumi.azurenative.fluidrelay.kotlin.outputs.FluidRelayEndpointsResponse
import com.pulumi.azurenative.fluidrelay.kotlin.outputs.IdentityResponse
import com.pulumi.azurenative.fluidrelay.kotlin.outputs.SystemDataResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import com.pulumi.azurenative.fluidrelay.kotlin.outputs.EncryptionPropertiesResponse.Companion.toKotlin as encryptionPropertiesResponseToKotlin
import com.pulumi.azurenative.fluidrelay.kotlin.outputs.FluidRelayEndpointsResponse.Companion.toKotlin as fluidRelayEndpointsResponseToKotlin
import com.pulumi.azurenative.fluidrelay.kotlin.outputs.IdentityResponse.Companion.toKotlin as identityResponseToKotlin
import com.pulumi.azurenative.fluidrelay.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin

/**
 * Builder for [FluidRelayServer].
 */
@PulumiTagMarker
public class FluidRelayServerResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: FluidRelayServerArgs = FluidRelayServerArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend FluidRelayServerArgsBuilder.() -> Unit) {
        val builder = FluidRelayServerArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): FluidRelayServer {
        val builtJavaResource =
            com.pulumi.azurenative.fluidrelay.FluidRelayServer(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return FluidRelayServer(builtJavaResource)
    }
}

/**
 * A FluidRelay Server.
 * Azure REST API version: 2022-06-01. Prior API version in Azure Native 1.x: 2021-03-12-preview.
 * Other available API versions: 2021-06-15-preview.
 * ## Example Usage
 * ### Create a Fluid Relay server
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var fluidRelayServer = new AzureNative.FluidRelay.FluidRelayServer("fluidRelayServer", new()
 *     {
 *         FluidRelayServerName = "myFluidRelayServer",
 *         Identity = new AzureNative.FluidRelay.Inputs.IdentityArgs
 *         {
 *             Type = AzureNative.FluidRelay.ResourceIdentityType.SystemAssigned,
 *         },
 *         Location = "west-us",
 *         ResourceGroup = "myResourceGroup",
 *         Storagesku = AzureNative.FluidRelay.StorageSKU.Basic,
 *         Tags =
 *         {
 *             { "Category", "sales" },
 *         },
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/fluidrelay/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := fluidrelay.NewFluidRelayServer(ctx, "fluidRelayServer", &fluidrelay.FluidRelayServerArgs{
 * 			FluidRelayServerName: pulumi.String("myFluidRelayServer"),
 * 			Identity: &fluidrelay.IdentityArgs{
 * 				Type: fluidrelay.ResourceIdentityTypeSystemAssigned,
 * 			},
 * 			Location:      pulumi.String("west-us"),
 * 			ResourceGroup: pulumi.String("myResourceGroup"),
 * 			Storagesku:    pulumi.String(fluidrelay.StorageSKUBasic),
 * 			Tags: pulumi.StringMap{
 * 				"Category": pulumi.String("sales"),
 * 			},
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.fluidrelay.FluidRelayServer;
 * import com.pulumi.azurenative.fluidrelay.FluidRelayServerArgs;
 * import com.pulumi.azurenative.fluidrelay.inputs.IdentityArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var fluidRelayServer = new FluidRelayServer("fluidRelayServer", FluidRelayServerArgs.builder()
 *             .fluidRelayServerName("myFluidRelayServer")
 *             .identity(IdentityArgs.builder()
 *                 .type("SystemAssigned")
 *                 .build())
 *             .location("west-us")
 *             .resourceGroup("myResourceGroup")
 *             .storagesku("basic")
 *             .tags(Map.of("Category", "sales"))
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:fluidrelay:FluidRelayServer myFluidRelayServer /subscriptions/{subscriptionId}/resourceGroups/{resourceGroup}/providers/Microsoft.FluidRelay/fluidRelayServers/{fluidRelayServerName}
 * ```
 */
public class FluidRelayServer internal constructor(
    override val javaResource: com.pulumi.azurenative.fluidrelay.FluidRelayServer,
) : KotlinCustomResource(javaResource, FluidRelayServerMapper) {
    /**
     * All encryption configuration for a resource.
     */
    public val encryption: Output<EncryptionPropertiesResponse>?
        get() = javaResource.encryption().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    encryptionPropertiesResponseToKotlin(args0)
                })
            }).orElse(null)
        })

    /**
     * The Fluid Relay Service endpoints for this server.
     */
    public val fluidRelayEndpoints: Output<FluidRelayEndpointsResponse>
        get() = javaResource.fluidRelayEndpoints().applyValue({ args0 ->
            args0.let({ args0 ->
                fluidRelayEndpointsResponseToKotlin(args0)
            })
        })

    /**
     * The Fluid tenantId for this server
     */
    public val frsTenantId: Output<String>
        get() = javaResource.frsTenantId().applyValue({ args0 -> args0 })

    /**
     * The type of identity used for the resource.
     */
    public val identity: Output<IdentityResponse>?
        get() = javaResource.identity().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    identityResponseToKotlin(args0)
                })
            }).orElse(null)
        })

    /**
     * The geo-location where the resource lives
     */
    public val location: Output<String>
        get() = javaResource.location().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Provision states for FluidRelay RP
     */
    public val provisioningState: Output<String>?
        get() = javaResource.provisioningState().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Sku of the storage associated with the resource
     */
    public val storagesku: Output<String>?
        get() = javaResource.storagesku().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * System meta data for this resource, including creation and modification information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * Resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object FluidRelayServerMapper : ResourceMapper<FluidRelayServer> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.fluidrelay.FluidRelayServer::class == javaResource::class

    override fun map(javaResource: Resource): FluidRelayServer = FluidRelayServer(
        javaResource as
            com.pulumi.azurenative.fluidrelay.FluidRelayServer,
    )
}

/**
 * @see [FluidRelayServer].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [FluidRelayServer].
 */
public suspend fun fluidRelayServer(
    name: String,
    block: suspend FluidRelayServerResourceBuilder.() -> Unit,
): FluidRelayServer {
    val builder = FluidRelayServerResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [FluidRelayServer].
 * @param name The _unique_ name of the resulting resource.
 */
public fun fluidRelayServer(name: String): FluidRelayServer {
    val builder = FluidRelayServerResourceBuilder()
    builder.name(name)
    return builder.build()
}
